bel_adn library

Support for doing something awesome.

More dartdocs go here.

Classes

Category
CategoryDataAccessObject
CategoryDataAccessObjectV2
CategoryExistsRequest
CategoryFindRequest
CategoryIndexRequest
CategoryPaginatedResource
CategoryStoreRequest
CategoryUpdateRequest
DataAccessObject<R extends Resource>
Represent a data access object
DataAccessObjectV1<R extends Resource, I extends IndexRequest, P extends PaginatedResource<R>, S extends StoreRequest, U extends UpdateRequest>
DataAccessObjectV2<R extends Resource, E extends ExistsRequest, F extends FindRequest>
DataTransferObject
An object that represent an intermediate between the API and the application
ExistsRequest
FindRequest
Host
An host is where we collect Medias from
HostDataAccessObject
Represent a Host
HostDataAccessObjectV2
HostExistsRequest
HostFindRequest
HostIndexRequest
HostPaginatedResource
HostStoreRequest
HostType
Represent the type of an Host.
HostTypeDataAccessObject
Represent a HostType
HostTypeDataAccessObjectV2
HostTypeExistsRequest
HostTypeFindRequest
HostTypeIndexRequest
HostTypePaginatedResource
HostTypeStoreRequest
HostTypeUpdateRequest
HostUpdateRequest
IndexRequest
Keyword
A Keyword represent a search string for an Host
KeywordDataAccessObject
Represent a Keyword
KeywordDataAccessObjectV2
KeywordExistsRequest
KeywordFindRequest
KeywordIndexRequest
KeywordPaginatedResource
KeywordStoreRequest
KeywordUpdateRequest
MagnifiqueCoupleClient
Represent a client to interact with the Magnifique Couple API
Media
Represent a Media
MediaDataAccessObject
The DataAccessObject for the Media class
MediaDataAccessObjectV2
MediaExistsRequest
MediaFindRequest
MediaIndexRequest
MediaPaginatedResource
MediaStoreRequest
MediaUpdateRequest
PaginatedResource<R extends Resource>
Represent a paginated resource
Represent a paginated resource
PaginatedResourceMeta
Represent a paginated resource meta
Represent a paginated resource meta link
Repository
Represent a repository
RequestDataTransfertObject
Resource
Represent a resource
ResponseDataTransfertObject<R extends Resource>
Represent a Search
SearchDataAccessObject
Represent a Search
SearchDataAccessObjectV2
SearchExistsRequest
SearchFindRequest
SearchIndexRequest
SearchPaginatedResource<T>
SearchStoreRequest
SearchUpdateRequest
StoreRequest
Topic
Represent a Topic
TopicDataAccessObject
The DataAccessObject for the Topic class
TopicDataAccessObjectV2
TopicExistsRequest
TopicFindRequest
TopicIndexRequest
TopicPaginatedResource
TopicStoreRequest
TopicUpdateRequest
UpdateRequest
V1
V2

Mixins

Destroyable<R extends Resource>
Existable<R extends Resource, E extends ExistsRequest>
Findable<R extends Resource, F extends FindRequest>
Indexable<R extends Resource, I extends IndexRequest, P extends PaginatedResource<R>>
Showable<R extends Resource>
Storable<R extends Resource, S extends StoreRequest>
Updatable<R extends Resource, U extends UpdateRequest>

Exceptions / Errors

ConflictMagnifiqueException
An exception thrown when the user is not authentified. All request to the API must be authentified with a bearer token.
MagnifiqueException
UnauthenticatedMagnifiqueException
An exception thrown when the user is not authentified. All request to the API must be authentified with a bearer token.