HostDataAccessObjectV2 class final

Inheritance
Annotations
  • @immutable

Constructors

HostDataAccessObjectV2(String baseUrl, Client client, Map<String, String>? defaultHeaders)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exists(covariant HostExistsRequest request) Future<bool>
inherited
find(covariant HostFindRequest request) Future<Host?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited