KeywordIndexRequest class final

Inheritance
Annotations
  • @immutable

Constructors

KeywordIndexRequest({bool? deleted, int? limit, int? page, String? keyword})
factory

Properties

deleted bool?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
keyword String?
final
limit int?
finalinherited
page int?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryParameters() Map<String, String>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited